Adding simple text is easy.

```python
--8<-- "codes/quick_start.py"
```

If you want a unified style, you can write it like this:

```python
--8<-- "codes/quick_start_many_import.py"
```

For more complex cases, consider using custom methods.

```python
--8<-- "codes/apply_sample.py"
```